@@ -1,6 +1,4 @@
 /* gcompris - menu2.c
- *
- * Time-stamp: <2007-08-22 01:27:17 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -661,10 +659,13 @@ item_event(GnomeCanvasItem *item, GdkEvent *event,  MenuItems *menuitems)
 
 	}
       else
-	{
+	// This should prevent an evil crash bug
+	// when the kids press 2 buttons at the same time
+	if (event->button.button == 1)
+	 {
 	  gc_sound_play_ogg ("sounds/level.wav", NULL);
 	  gc_board_run_next (board);
-	}
+	 }
 
       break;
 
