@@ -261,14 +261,12 @@ static void start_board (GcomprisBoard *agcomprisBoard)
       /**/
       while( (filename = gc_file_find_absolute("%s/board%d_0.xml",
 							 gcomprisBoard->boarddir,
-							 gcomprisBoard->maxlevel++,
+							 gcomprisBoard->maxlevel,
 							 NULL)) )
 	{
+	  gcomprisBoard->maxlevel++;
 	  g_free(filename);
-
 	}
-
-      /**/
       gcomprisBoard->maxlevel--;
 
       gc_bar_set(GC_BAR_CONFIG|GC_BAR_LEVEL);
@@ -929,6 +927,7 @@ void target_point_hide()
 static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 {
     static GnomeCanvasItem *shadow_item=NULL;
+    static GnomeCanvasItem *dragged;
     double item_x, item_y;
     Shape *shape, *found_shape;
 
@@ -1007,11 +1006,15 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
                 gdk_pixbuf_unref(dest);
                 gdk_pixbuf_unref(pixmap);
             }
+	    dragged = shape->item;
             gnome_canvas_item_reparent(shape->item, GNOME_CANVAS_GROUP(shape_list_root_item->parent));
             gnome_canvas_item_raise_to_top(shape->item);
             gc_drag_item_move(event);
             break;
         case GDK_MOTION_NOTIFY:
+	    if (item != dragged)
+		break;
+
             gc_drag_item_move(event);
 
             item_x = event->button.x;
@@ -1036,6 +1039,9 @@ static gint item_event_drag(GnomeCanvasItem *item, GdkEvent *event, gpointer dat
             target_point_switch_on(found_shape);
             break;
         case GDK_BUTTON_RELEASE:
+	    if (item != dragged)
+		break;
+
             item_x = event->button.x;
             item_y = event->button.y;
             gnome_canvas_item_w2i(item->parent, &item_x, &item_y);
@@ -1699,7 +1705,7 @@ parse_doc(xmlDocPtr doc)
     {
       Shape *shape;
 
-      i = list_length == 1 ? 0 : g_random_int_range(0, g_list_length(shape_list_init)-1);
+      i = g_random_int_range(0, list_length);
       shape = g_list_nth_data(shape_list_init, i);
       add_shape_to_canvas(shape);
 
