@@ -1,6 +1,4 @@
 /* gcompris - smallnumbers.c
- *
- * Time-stamp: <2007-08-22 01:27:14 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -248,6 +246,24 @@ static gint key_press(guint keyval, gchar *commit_str, gchar *preedit_str)
 		 (GFunc) smallnumbers_gotkey_item,
 		 GINT_TO_POINTER(keyval));
 
+  if(gcomprisBoard->sublevel>gcomprisBoard->number_of_sublevel)
+    {
+      /* Try the next level */
+      gcomprisBoard->level++;
+      if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
+	gc_score_end();
+	gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
+	return TRUE;
+      }
+      gamewon = TRUE;
+      smallnumbers_destroy_all_items();
+      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
+    }
+  else
+    {
+      gc_score_set(gcomprisBoard->sublevel);
+    }
+
   return TRUE;
 }
 
@@ -481,23 +497,6 @@ static void player_win(GnomeCanvasItem *item)
   gcomprisBoard->sublevel++;
   gc_score_set(gcomprisBoard->sublevel);
 
-  if(gcomprisBoard->sublevel>gcomprisBoard->number_of_sublevel)
-    {
-      /* Try the next level */
-      gcomprisBoard->level++;
-      if(gcomprisBoard->level>gcomprisBoard->maxlevel) { // the current board is finished : bail out
-	gc_score_end();
-	gc_bonus_end_display(GC_BOARD_FINISHED_RANDOM);
-	return;
-      }
-      gamewon = TRUE;
-      smallnumbers_destroy_all_items();
-      gc_bonus_display(gamewon, GC_BONUS_SMILEY);
-    }
-  else
-    {
-      gc_score_set(gcomprisBoard->sublevel);
-    }
 }
 
 static void player_loose()
@@ -591,7 +590,8 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   label = g_strdup_printf(_("<b>%s</b> configuration\n for profile <b>%s</b>"),
 			  agcomprisBoard->name, aProfile ? aProfile->name : "");
 
-  gc_board_config_window_display(label, (GcomprisConfCallback )conf_ok);
+  GcomprisBoardConf *bconf;
+  bconf = gc_board_config_window_display(label, (GcomprisConfCallback )conf_ok);
 
   g_free(label);
 
@@ -606,9 +606,9 @@ smallnumber_config_start(GcomprisBoard *agcomprisBoard,
   else
     with_sound = FALSE;
 
-  GtkCheckButton  *sound_control = gc_board_config_boolean_box(_("Enable sounds"), "with_sound", with_sound);
+  GtkCheckButton  *sound_control = gc_board_config_boolean_box(bconf, _("Enable sounds"), "with_sound", with_sound);
 
-  GtkComboBox *sound_box = gc_board_config_combo_locales_asset( _("Select sound locale"),
+  GtkComboBox *sound_box = gc_board_config_combo_locales_asset(bconf, _("Select sound locale"),
 							 saved_locale_sound,
 							 "voices/$LOCALE/colors/purple.ogg");
 
