@@ -31,10 +31,6 @@
 
 #include "gcompris.h"
 
-extern GnomeCanvas *canvas;
-
-typedef void (*sighandler_t)(int);
-
 /* GdkPixbuf RGBA C-Source image dump for a NULL image*/
 #ifdef __SUNPRO_C
 #pragma align 4 (null_img)
@@ -86,7 +82,7 @@ GdkPixbuf *gc_pixmap_load(const gchar *format, ...)
   filename = gc_file_find_absolute(pixmapfile);
 
   if(filename)
-    pixmap = gc_net_load_pixmap(filename);
+     pixmap = gdk_pixbuf_new_from_file(filename,NULL);
 
   if (!filename || !pixmap)
     {
@@ -541,8 +537,7 @@ gc_file_find_absolute(const gchar *format, ...)
   va_end (args);
 
   /* Check it's already found */
-  if( g_file_test (filename, G_FILE_TEST_EXISTS)
-      || gc_net_is_url(filename) )
+  if( g_file_test (filename, G_FILE_TEST_EXISTS))
     {
       return filename;
     }
@@ -551,6 +546,9 @@ gc_file_find_absolute(const gchar *format, ...)
    * Search it on the file system
    */
 
+  if(properties->server)
+  	dir_to_search[i++] = "";
+  dir_to_search[i++] = properties->user_dir;
   dir_to_search[i++] = properties->package_data_dir;
   dir_to_search[i++] = NULL;
 
@@ -601,6 +599,7 @@ gc_file_find_absolute(const gchar *format, ...)
 		  g_free(filename2);
 		  goto FOUND;
 		}
+	      g_free(absolute_filename);
 
 	      /* Now check if this file is on the net */
 	      if((absolute_filename = gc_net_get_url_from_file(filename2, NULL)))
@@ -639,6 +638,35 @@ gc_file_find_absolute(const gchar *format, ...)
   return absolute_filename;
 }
 
+gchar*
+gc_file_find_absolute_writeable(const gchar *format, ...)
+{
+  gchar *filename, *absolute_filename, *dirname;
+  GcomprisProperties *prop;
+  va_list args;
+
+  va_start (args, format);
+  filename = g_strdup_vprintf (format, args);
+  va_end (args);
+
+  prop = gc_prop_get();
+  absolute_filename = g_build_filename(prop->user_dir, filename,NULL);
+  g_free(filename);
+  dirname = g_path_get_dirname(absolute_filename);
+  if(!g_file_test(dirname, G_FILE_TEST_IS_DIR))
+    {
+      if(g_mkdir_with_parents(dirname, 0755))
+      {
+      	g_free(absolute_filename);
+	absolute_filename=NULL;
+      }
+    }
+  g_free(dirname);
+  if(absolute_filename)
+  	gc_cache_add(absolute_filename);
+  return absolute_filename;
+}
+
 /** Create a directory if needed.
  *
  * \param rootdir: the directory to create
