@@ -1,6 +1,4 @@
 /* gcompris - gc_core.h
- *
- * Time-stamp: <2007-08-22 01:21:22 bruno>
  *
  * Copyright (C) 2006 Bruno Coudoin
  *
@@ -48,11 +46,4 @@ void gc_mime_type_load();
 /** log */
 void gc_log_start (GcomprisBoard *gcomprisBoard);
 
-/** cache */
-void gc_cache_init(int max_size);
-void gc_cache_end();
-void gc_cache_clear();
-gchar *gc_cache_get(gchar *url);
-gchar *gc_cache_insert(const gchar *url, const char *buffer, gssize length);
-
 #endif
