@@ -73,7 +73,7 @@ static void single_instance_release();
  * For the Activation dialog
  */
 #ifdef STATIC_MODULE
-int gc_activation_check(char *code);
+gint gc_activation_check(const char *code);
 static void activation_enter_callback(GtkWidget *widget,
 				      GtkWidget *entry );
 static void activation_done();
@@ -668,19 +668,18 @@ static void setup_window ()
    * ------------------------
    */
   icon_file = g_strconcat(properties->system_icon_dir, "/gcompris.png", NULL);
-  if (!g_file_test (icon_file, G_FILE_TEST_EXISTS)) {
-      /* Now check if this file is on the net */
-      icon_file = gc_net_get_url_from_file("gcompris.png", NULL);
-  }
 
   if(!icon_file)
       g_warning ("Couldn't find file %s !", icon_file);
 
-  icon_pixbuf = gdk_pixbuf_new_from_file(icon_file,NULL);
+  GError *error = NULL;
+  icon_pixbuf = gdk_pixbuf_new_from_file(icon_file, &error);
   if (!icon_pixbuf)
     {
-      g_warning ("Failed to load pixbuf file: %s\n",
-               icon_file);
+      g_warning ("Failed to load pixbuf file: %s / %s\n",
+		 icon_file, error->message);
+      g_error_free (error);
+
     }
   g_free(icon_file);
 
@@ -815,13 +814,18 @@ display_activation_dialog()
   int board_count = 0;
   int gc_board_number_in_demo = 0;
   GList *list;
-  guint  key_is_valid = 0;
+  gint  key_is_valid = 0;
 
   key_is_valid = gc_activation_check(properties->key);
 
   if(key_is_valid == 1)
     return FALSE;
-
+  else if(key_is_valid == 2)
+    {
+      g_free ( gc_prop_get()->key );
+      gc_prop_get()->key = strdup("");
+      gc_prop_save(properties);
+    }
   /* Count non menu boards */
   for (list = gc_menu_get_boards(); list != NULL; list = list->next)
     {
@@ -869,8 +873,9 @@ display_activation_dialog()
  * Return -1 if the code is not valid
  *        0  if the code is valid but out of date
  *        1  if the code is valid and under 2 years
+ *        2  this is a demo code, must request the code again
  */
-int gc_activation_check(char *code)
+gint gc_activation_check(const char *code)
 {
 #ifdef  DISABLE_ACTIVATION_CODE
   return 1;
@@ -879,11 +884,18 @@ int gc_activation_check(char *code)
   int i;
   char crc1 = 0;
   char crc2 = 0;
-  char codeddate[4];
+  char codeddate[5];
 
   if(strlen(code) != 6)
     return -1;
 
+  // A special code to test the full version without
+  // saving the activation
+  if (strncmp(code, "123321", 6) == 0)
+    {
+      return 2;
+    }
+
   for(i=3; i>=0; i--)
     {
       value |= code[i] & 0x07;
@@ -926,9 +938,12 @@ static void
 activation_enter_callback( GtkWidget *entry,
 			   GtkWidget *notused )
 {
-  switch(gc_activation_check((char *)gtk_entry_get_text(GTK_ENTRY(entry))))
+  const char *code = gtk_entry_get_text(GTK_ENTRY(entry));
+
+  switch(gc_activation_check(code))
     {
     case 1:
+    case 2:
       gc_prop_get()->key = strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
       gc_prop_save(properties);
       gtk_entry_set_text(GTK_ENTRY(entry), "GOOD");
@@ -1905,6 +1920,8 @@ main (int argc, char *argv[])
 
   gc_skin_load(properties->skin);
 
+  gc_sound_build_music_list();
+
   if(properties->music || properties->fx)
     gc_sound_init();
 
