@@ -22,6 +22,8 @@
 
 #include "gcompris.h"
 
+void gc_wordlist_dump(GcomprisWordlist *wl);
+
 /** Load a wordlist formatted xml file. It contains a list of words.
  *
  * The xml file format must be like this:
@@ -62,13 +64,11 @@ GcomprisWordlist
   xmlNodePtr wlNode;
   xmlNodePtr node;
   xmlNodePtr wordsNode;
-  int i;
-  guint number_of_level = 0;
+  guint level;
 
   GcomprisWordlist     *wordlist;
   xmlChar              *text;
 
-  gchar               **wordsArray;
   GSList                *words = NULL;
 
   if (!format)
@@ -84,19 +84,21 @@ GcomprisWordlist
   if(!xmlfilename)
     {
       g_warning("Couldn't find file %s !", filename);
-      g_free(xmlfilename);
+      g_free(filename);
       return NULL;
     }
 
   g_warning("Wordlist found %s\n", xmlfilename);
 
   xmldoc = xmlParseFile(xmlfilename);
-  g_free(xmlfilename);
 
   if(!xmldoc){
     g_warning("Couldn't parse file %s !", xmlfilename);
+    g_free(filename);
+    g_free(xmlfilename);
     return NULL;
   }
+  g_free(xmlfilename);
 
   if(/* if there is no root element */
      !xmldoc->children ||
@@ -106,6 +108,7 @@ GcomprisWordlist
      g_strcasecmp((gchar *)xmldoc->children->name,(gchar *)"GCompris")!=0) {
     g_warning("No Gcompris node");
     xmlFreeDoc(xmldoc);
+    g_free(filename);
     return NULL;
   }
 
@@ -118,6 +121,7 @@ GcomprisWordlist
      g_strcasecmp((gchar *)wlNode->name,"Wordlist")!=0) {
     g_warning("No wordlist node %s", (wlNode == NULL) ? (gchar *)wlNode->name : "NULL node");
     xmlFreeDoc(xmldoc);
+    g_free(filename);
     return NULL;
   }
 
@@ -174,50 +178,62 @@ GcomprisWordlist
       break;
     }
 
-    text = xmlNodeGetContent ( wordsNode);
-
-    wordsArray = g_strsplit_set ((const gchar *) text,
-				 (const gchar *) " \n\t",
-				 0);
-
-    g_warning("Wordlist read : %s", text);
-
-    xmlFree (text);
-
-    i=0;
-    while (wordsArray[i] != NULL) {
-      if (wordsArray[i][0]!='\0')
-	words = g_slist_append( words, g_strdup( wordsArray[i]));
-      i++;
-    }
-
-    g_strfreev ( wordsArray);
-
-
-    /* initialise LevelWordlist struct */
-    LevelWordlist *level_words = g_malloc0(sizeof(LevelWordlist));
-
-    number_of_level++;
-
+    level=-1;
     text = xmlGetProp ( node,
-			(const xmlChar *) "value");
+		    (const xmlChar *) "value");
     if (text) {
-      level_words->level = atoi((gchar *) text);
-      xmlFree (text);
+	    level = atoi((gchar *) text);
+	    xmlFree (text);
     }
-
-    level_words->words = words;
-
-    wordlist->levels_words = g_slist_append( wordlist->levels_words, level_words);
+    text = xmlNodeGetContent ( wordsNode);
+    gc_wordlist_set_wordlist(wordlist, level, (const gchar*)text);
+    xmlFree(text);
 
     node = node->next;
   }
-
-  wordlist->number_of_level = number_of_level;
-
+  xmlFreeDoc(xmldoc);
   return wordlist;
 }
 
+void gc_wordlist_dump(GcomprisWordlist *wl)
+{
+	GSList *level, *words;
+
+	printf("Wordlist dump\n");
+	printf("filename:%s\n",wl->filename);
+	printf("number of level:%d\n",wl->number_of_level);
+
+	for(level = wl->levels_words; level; level = level->next)
+	{
+		printf("Level %d\n", ((LevelWordlist*)level->data)->level);
+		printf("Words :");
+		for(words=((LevelWordlist*)level->data)->words; words; words=words->next)
+		{
+			printf(" %s", (char*)words->data);
+		}
+		puts("");
+	}
+}
+
+LevelWordlist*gc_wordlist_get_levelwordlist(GcomprisWordlist *wordlist, guint level)
+{
+	GSList *lev_list, *list;
+	LevelWordlist *lw;
+
+	if(!wordlist)
+		return NULL;
+
+	lev_list = wordlist->levels_words;
+
+	for (list = lev_list; list != NULL; list = list->next)
+	{
+		lw = list->data;
+		if(lw->level == level)
+			return lw;
+	}
+	return NULL;
+}
+
 /** get a random word from the wordlist in the given level
  *
  * \param wordlist: the wordlist
@@ -228,36 +244,37 @@ GcomprisWordlist
 gchar *
 gc_wordlist_random_word_get(GcomprisWordlist *wordlist, guint level)
 {
-  GSList *lev_list, *list;
+	LevelWordlist *lw;
+	gchar *word;
 
-  if(!wordlist)
-    return NULL;
+	if(level>wordlist->number_of_level)
+		level = wordlist->number_of_level;
 
-  lev_list = wordlist->levels_words;
+	lw = gc_wordlist_get_levelwordlist(wordlist, level);
+	if(!lw)
+		return NULL;
 
-  /* cap to the number_of_level */
-  if(level > wordlist->number_of_level)
-    level = wordlist->number_of_level;
+	g_warning("Level : %d", lw->level);
 
-  for (list = lev_list; list != NULL; list = list->next)
-    {
-      LevelWordlist *lw = list->data;
+	/* We got the proper level, find a random word */
+	word = (gchar *)g_slist_nth_data(lw->words,
+			RAND(0, g_slist_length(lw->words))
+			);
+	g_warning("returning random word '%s'", word);
+	return(g_strdup(word));
+}
 
-      if(lw->level == level)
-	{
-	  gchar *word;
-	  g_warning("Level : %d", lw->level);
+static void gc_wordlist_free_level(LevelWordlist *lw)
+{
+	GSList *words;
 
-	  /* We got the proper level, find a random word */
-	  word = (gchar *)g_slist_nth_data(lw->words,
-					  RAND(0, g_slist_length(lw->words)-1)
-					  );
-	  g_warning("returning random word '%s'", word);
-	  return(g_strdup(word));
-	}
-    }
+	if(!lw)
+		return;
 
-  return NULL;
+	for (words = lw->words; words !=NULL; words = words->next)
+		g_free(words->data);
+	g_slist_free(lw->words);
+	g_free(lw);
 }
 
 /** call it to free a GcomprisWordlist as returned by gc_wordlist_get_from_file
@@ -268,7 +285,7 @@ gc_wordlist_random_word_get(GcomprisWordlist *wordlist, guint level)
 void
 gc_wordlist_free(GcomprisWordlist *wordlist)
 {
-  GSList *list, *words;
+  GSList *list;
 
   if(!wordlist)
     return;
@@ -280,11 +297,103 @@ gc_wordlist_free(GcomprisWordlist *wordlist)
 
   for ( list = wordlist->levels_words; list !=NULL; list=list->next){
     LevelWordlist *lw = (LevelWordlist *)list->data;
-    for ( words = lw->words; words !=NULL; words = words->next)
-      g_free(words->data);
-    g_slist_free(lw->words);
-    g_free(lw);
+    gc_wordlist_free_level(lw);
   }
   g_slist_free ( wordlist->levels_words);
   g_free (wordlist);
 }
+
+void gc_wordlist_set_wordlist(GcomprisWordlist *wordlist, guint level, const gchar*text)
+{
+	LevelWordlist *lw;
+	GSList *words=NULL;
+	gchar **wordsArray;
+	int i;
+	
+	g_warning("wordlist : add level=%d text=%s\n", level, text);
+	/* remove level */
+	if((lw = gc_wordlist_get_levelwordlist(wordlist, level)))
+	{
+		g_warning("remove level %d", lw->level);
+		wordlist->levels_words = g_slist_remove(wordlist->levels_words, lw);
+		gc_wordlist_free_level(lw);
+		wordlist->number_of_level--;
+	}
+
+	/* add new level */
+	wordsArray = g_strsplit_set (text, " \n\t", 0);
+
+	i=0;
+	for(i=0;wordsArray[i] != NULL; i++)
+		if (wordsArray[i][0]!='\0' &&
+			!g_slist_find_custom(words, wordsArray[i], (GCompareFunc)strcmp))
+				words = g_slist_append( words, g_strdup(wordsArray[i]));
+
+	g_strfreev ( wordsArray);
+
+	if(words==NULL)
+		return;
+
+	/* initialise LevelWordlist struct */
+	LevelWordlist *level_words = g_malloc0(sizeof(LevelWordlist));
+
+	level_words->words = words;
+	level_words->level = level;
+
+	wordlist->number_of_level++;
+	wordlist->levels_words = g_slist_append( wordlist->levels_words, level_words);
+}
+
+void gc_wordlist_save(GcomprisWordlist *wordlist)
+{
+	GSList *listlevel,*listword;
+	LevelWordlist *level;
+	gchar *filename, *tmp;
+	xmlNodePtr wlnode, levelnode, node;
+	xmlDocPtr doc;
+
+	if(!wordlist)
+		return;
+	doc = xmlNewDoc(BAD_CAST XML_DEFAULT_VERSION);
+	if(!doc)
+		return;
+
+	node = xmlNewNode(NULL, BAD_CAST "GCompris");
+	xmlDocSetRootElement(doc,node);
+	wlnode = xmlNewChild(node, NULL, BAD_CAST "Wordlist", NULL);
+
+	if(wordlist->name)
+		xmlSetProp(wlnode, BAD_CAST "name", BAD_CAST wordlist->name);
+	if(wordlist->description)
+		xmlSetProp(wlnode, BAD_CAST "description", BAD_CAST wordlist->description);
+	if(wordlist->locale)
+		xmlSetProp(wlnode, BAD_CAST "locale", BAD_CAST wordlist->locale);
+	for(listlevel = wordlist->levels_words; listlevel; listlevel = listlevel->next)
+	{
+		level = (LevelWordlist*)listlevel->data;
+		levelnode = xmlNewChild(wlnode, NULL, BAD_CAST "level", NULL);
+		if((tmp = g_strdup_printf("%d", level->level)))
+		{
+			xmlSetProp(levelnode, BAD_CAST "value", BAD_CAST tmp);
+			g_free(tmp);
+		}
+		for(listword = level->words; listword; listword=listword->next)
+		{
+			xmlNodeAddContent(levelnode, BAD_CAST listword->data);
+			xmlNodeAddContent(levelnode, BAD_CAST " ");
+		}
+	}
+
+	filename = gc_file_find_absolute_writeable(wordlist->filename);
+	if(filename)
+	{
+		if(xmlSaveFormatFileEnc(filename, doc, NULL, 1)<0)
+		{
+			g_warning("Fail to write %s", filename);
+			g_free(filename);
+		}
+		g_free(filename);
+	}
+	xmlFreeDoc(doc);
+}
+
